==> jc-1.4.0.tar.gz: soot/grimp/internal/GArrayRef.h <==
// public class soot.grimp.internal.GArrayRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31e9d2336bcc57e0 soot_grimp_internal_GArrayRef
// @dep_class 232c780c802c1e59 soot_jimple_internal_JArrayRef

// header file dependencies
// @dep_header soot_jimple_internal_JArrayRef

#include "soot/jimple/internal/JArrayRef.h"

#ifndef _JC_soot_grimp_internal_GArrayRef_H_
#define _JC_soot_grimp_internal_GArrayRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GArrayRef$sub_refs	_jc_soot_grimp_internal_GArrayRef$sub_refs;
typedef struct _jc_soot_grimp_internal_GArrayRef$sub_nonrefs	_jc_soot_grimp_internal_GArrayRef$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GArrayRef$refs	_jc_soot_grimp_internal_GArrayRef$refs;
typedef struct _jc_soot_grimp_internal_GArrayRef$nonrefs	_jc_soot_grimp_internal_GArrayRef$nonrefs;
typedef struct _jc_soot_grimp_internal_GArrayRef$object	_jc_soot_grimp_internal_GArrayRef$object;

typedef const struct _jc_soot_grimp_internal_GArrayRef$vmethods	_jc_soot_grimp_internal_GArrayRef$vmethods;
typedef const struct _jc_soot_grimp_internal_GArrayRef$vtable	_jc_soot_grimp_internal_GArrayRef$vtable;
typedef const struct _jc_soot_grimp_internal_GArrayRef$vtype	_jc_soot_grimp_internal_GArrayRef$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GArrayRef$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GArrayRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
extern jint _jc_soot_grimp_internal_GArrayRef$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GArrayRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
extern void _jc_soot_grimp_internal_GArrayRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GArrayRef$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$49ce0d4a4e59c2a6;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GArrayRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GArrayRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_JArrayRef$vmethods	soot_jimple_internal_JArrayRef;
	_jc_soot_grimp_internal_GArrayRef$vmethods	soot_grimp_internal_GArrayRef;
};

// Vtype
struct _jc_soot_grimp_internal_GArrayRef$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GArrayRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GArrayRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GArrayRef$refs {
    _jc_soot_grimp_internal_GArrayRef$sub_refs	soot_grimp_internal_GArrayRef;
    _jc_soot_jimple_internal_JArrayRef$sub_refs	soot_jimple_internal_JArrayRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GArrayRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GArrayRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_JArrayRef$sub_nonrefs	soot_jimple_internal_JArrayRef;
    _jc_soot_grimp_internal_GArrayRef$sub_nonrefs	soot_grimp_internal_GArrayRef;
};

// Object instance structure
struct _jc_soot_grimp_internal_GArrayRef$object {
	_jc_soot_grimp_internal_GArrayRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GArrayRef$vtype	*vtype;
	_jc_soot_grimp_internal_GArrayRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GArrayRef$vtype _jc_soot_grimp_internal_GArrayRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GArrayRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GArrayRef$class_object;

#endif	/* _JC_soot_grimp_internal_GArrayRef_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GArrayRef.h <==
// public class soot.grimp.internal.GArrayRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31e9d2336bcc57e0 soot_grimp_internal_GArrayRef
// @dep_class 232c780c802c1e59 soot_jimple_internal_JArrayRef

// header file dependencies
// @dep_header soot_jimple_internal_JArrayRef

#include "soot/jimple/internal/JArrayRef.h"

#ifndef _JC_soot_grimp_internal_GArrayRef_H_
#define _JC_soot_grimp_internal_GArrayRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GArrayRef$sub_refs	_jc_soot_grimp_internal_GArrayRef$sub_refs;
typedef struct _jc_soot_grimp_internal_GArrayRef$sub_nonrefs	_jc_soot_grimp_internal_GArrayRef$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GArrayRef$refs	_jc_soot_grimp_internal_GArrayRef$refs;
typedef struct _jc_soot_grimp_internal_GArrayRef$nonrefs	_jc_soot_grimp_internal_GArrayRef$nonrefs;
typedef struct _jc_soot_grimp_internal_GArrayRef$object	_jc_soot_grimp_internal_GArrayRef$object;

typedef const struct _jc_soot_grimp_internal_GArrayRef$vmethods	_jc_soot_grimp_internal_GArrayRef$vmethods;
typedef const struct _jc_soot_grimp_internal_GArrayRef$vtable	_jc_soot_grimp_internal_GArrayRef$vtable;
typedef const struct _jc_soot_grimp_internal_GArrayRef$vtype	_jc_soot_grimp_internal_GArrayRef$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GArrayRef$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GArrayRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GArrayRef$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GArrayRef$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_GArrayRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GArrayRef$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$49ce0d4a4e59c2a6;
extern _jc_method _jc_soot_grimp_internal_GArrayRef$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GArrayRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GArrayRef$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GArrayRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_JArrayRef$vmethods	soot_jimple_internal_JArrayRef;
	_jc_soot_grimp_internal_GArrayRef$vmethods	soot_grimp_internal_GArrayRef;
};

// Vtype
struct _jc_soot_grimp_internal_GArrayRef$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GArrayRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GArrayRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GArrayRef$refs {
    _jc_soot_grimp_internal_GArrayRef$sub_refs	soot_grimp_internal_GArrayRef;
    _jc_soot_jimple_internal_JArrayRef$sub_refs	soot_jimple_internal_JArrayRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GArrayRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GArrayRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_JArrayRef$sub_nonrefs	soot_jimple_internal_JArrayRef;
    _jc_soot_grimp_internal_GArrayRef$sub_nonrefs	soot_grimp_internal_GArrayRef;
};

// Object instance structure
struct _jc_soot_grimp_internal_GArrayRef$object {
	_jc_soot_grimp_internal_GArrayRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GArrayRef$vtype	*vtype;
	_jc_soot_grimp_internal_GArrayRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GArrayRef$vtype _jc_soot_grimp_internal_GArrayRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GArrayRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GArrayRef$class_object;

#endif	/* _JC_soot_grimp_internal_GArrayRef_H_ */
